# API Reference

```{eval-rst}

.. toctree::
    :maxdepth: 1

    cli


Modules
=======

.. currentmodule:: uv_workon

.. autosummary::
   :toctree: generated/
   :template: autodocsumm/module.rst

   cli
   core
   validate
   utils


```
